@@ -1,23 +1,9 @@
 import json
 
-from stream_chat.exceptions import StreamChannelException
+from stream_chat.base.channel import ChannelInterface, add_user_id
 
 
-class Channel(object):
-    def __init__(self, client, channel_type, channel_id=None, custom_data=None):
-        self.channel_type = channel_type
-        self.id = channel_id
-        self.client = client
-        self.custom_data = custom_data
-        if self.custom_data is None:
-            self.custom_data = {}
-
-    @property
-    def url(self):
-        if self.id is None:
-            raise StreamChannelException("channel does not have an id")
-        return "channels/{}/{}".format(self.channel_type, self.id)
-
+class Channel(ChannelInterface):
     def send_message(self, message, user_id):
         """
         Send a message to this channel
@@ -210,7 +196,7 @@ class Channel(object):
         List the message replies for a parent message
 
         :param parent_id: The message parent id, ie the top of the thread
-        :param options: Pagination params, ie {limit:10, idlte: 10}
+        :param options: Pagination params, ie {limit:10, id_lte: 10}
         :return: A response with a list of messages
         """
         return self.client.get("messages/{}/replies".format(parent_id), params=options)
@@ -220,7 +206,7 @@ class Channel(object):
         List the reactions, supports pagination
 
         :param message_id: The message id
-        :param options: Pagination params, ie {"limit":10, "idlte": 10}
+        :param options: Pagination params, ie {"limit":10, "id_lte": 10}
         :return: A response with a list of reactions
         """
         return self.client.get(
@@ -231,7 +217,7 @@ class Channel(object):
         """
         Bans a user from this channel
 
-        :param user_id: the ID of the user to ban
+        :param target_id: the ID of the user to ban
         :param options: additional ban options, ie {"timeout": 3600, "reason": "offensive language is not allowed here"}
         :return: The server response
         """
@@ -243,7 +229,7 @@ class Channel(object):
         """
         Removes the ban for a user on this channel
 
-        :param user_id: the ID of the user to unban
+        :param target_id: the ID of the user to unban
         :return: The server response
         """
         return self.client.unban_user(
@@ -285,7 +271,3 @@ class Channel(object):
 
     def show(self, user_id):
         return self.client.post("{}/show".format(self.url), data={"user_id": user_id})
-
-
-def add_user_id(payload, user_id):
-    return {**payload, "user": {"id": user_id}}
