@@ -1,11 +1,12 @@
 from operator import itemgetter
 
+import uuid
+
 import jwt
 import pytest
 import sys
-import uuid
 from stream_chat import StreamChat
-from stream_chat.exceptions import StreamAPIException
+from stream_chat.base.exceptions import StreamAPIException
 
 
 @pytest.mark.incremental
